<?xml version="1.0" encoding="windows-1250"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns:p="http://kpi.fei.tuke.sk/practices">
    
    <xsl:variable name="objectivePrefix">objId_</xsl:variable>
    
    <!-- =============================== module ============================= -->
    <!-- Main tamplate for module -->
    <xsl:template match="p:module">
        <div class="objectives">Ciele
        </div>
        <ol>
            <xsl:apply-templates select="p:objective"/>
        </ol>
        
        <div class="additional-line"/>
        
        <div class="introduction">vod</div>
        <ol>
            <xsl:apply-templates select="p:introduction"/>
        </ol>
        
        <div class="content">Postup
        </div>
        <ol>
            <xsl:apply-templates select="p:step"/>
        </ol>        
        
        <xsl:if test="count(p:resource) > 0">
            <div class="resources">Zdroje
            </div>
            <ol>
                <xsl:apply-templates select="p:resource"/>
            </ol>
        </xsl:if>
        
        <xsl:if test="count(p:additional/p:task | p:additional/p:resource) > 0">
            <div class="additional-line"/>
        </xsl:if>
        
        <xsl:if test="count(p:additional/p:task) > 0">
            <div class="additional-tasks">Doplujce lohy
            </div>
            <ol>
                <xsl:apply-templates select="p:additional/p:task"/>
            </ol>
        </xsl:if>

        <xsl:if test="count(p:additional/p:resource) > 0">
            <div class="additional-resources">Doplujce zdroje
            </div>
            <ol>
                <xsl:apply-templates select="p:additional/p:resource"/>
            </ol>
        </xsl:if>

    </xsl:template>
    
    <!-- ======================= objective ===================== -->
    <xsl:template match="p:objective">
        <li class="objective">
            <xsl:attribute name="id">
                <xsl:value-of select="concat($objectivePrefix, @id)"/>
            </xsl:attribute>
            <span class="clickable">
            <xsl:apply-templates/>
            </span>
            <span class="add-func">
                <input type="checkbox" checked="checked">
                    <xsl:attribute name="class">
                        <xsl:text>objectiveCheckbox </xsl:text>
                        <xsl:value-of select="concat($objectivePrefix, @id)"/>
                    </xsl:attribute>
                </input>
            </span>
        </li>
    </xsl:template>    
    
    <!-- ========================== step ========================== -->
    <xsl:template match="p:step">
        <!--<xsl:variable name="objectives" select="//p:objective"/>-->
        <li class="step">
            <xsl:attribute name="class">
                <xsl:variable name="objIds" select="tokenize(@objectives, ' ')"/>
                <xsl:for-each select="$objIds">
                        <xsl:variable name="tempId" select="."/>  
                        <xsl:value-of select="concat($objectivePrefix,$tempId)"/>
                        <xsl:if test="$tempId != $objIds[last()]">
                            <xsl:text> </xsl:text>
                        </xsl:if>
                    </xsl:for-each>
            </xsl:attribute>
            <div class="step">
<!--                <xsl:attribute name="title">
                    <xsl:variable name="objIds" select="tokenize(@objectives, ' ')"/>
                    <xsl:choose>
                        <xsl:when test="count($objIds) > 1">Ciele: </xsl:when>
                        <xsl:otherwise>Cie: </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text>&#xa;</xsl:text>
                    <xsl:for-each select="$objIds">
                        <xsl:variable name="tempId" select="."/>  
                        <xsl:value-of select="normalize-space($objectives[@id = $tempId])"/>
                        <xsl:if test="$tempId != $objIds[last()]">
                            <xsl:text>&#xa;&#xa;</xsl:text>
                        </xsl:if>
                    </xsl:for-each>
                </xsl:attribute>-->
                <xsl:apply-templates/>
            </div>
        </li>
    </xsl:template>
    
    <!-- ======================= introduction ======================== -->
    <xsl:template match="p:introduction">
        <xsl:apply-templates/>
    </xsl:template>
    
    <!-- ======================= resource ======================== -->
    <xsl:template match="p:resource">
        <li class="resource">
            <xsl:apply-templates/>
        </li>
    </xsl:template>

    <!-- ============= task, comment, link, image, source =============== -->
    <xsl:template match="p:task">
        <div class="task">
            <b>
                <xsl:choose>
                    <xsl:when test="count(p:solution) > 0 and count(p:lecturer) = 0">
                        Rieen loha:
                    </xsl:when>
                    <xsl:otherwise>
                        loha:
                    </xsl:otherwise>
                </xsl:choose>
            </b>
            <xsl:apply-templates/>
        </div>
    </xsl:template>
    
    <xsl:template match="p:solution">
        <div class="solution" style="block">
            <b>Rieenie:</b>
            <xsl:apply-templates/>
        </div>
    </xsl:template>

    <xsl:template match="p:comment">
        <div class="comment">
            <b>
                Poznmka:
            </b>
            <xsl:apply-templates/>
        </div>
    </xsl:template>

    <xsl:template match="p:link">
        <a target="_blank">
            <xsl:attribute name="href">
                <xsl:choose>
                    <xsl:when test="@href">
                        <xsl:value-of select="@href"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="." />
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="p:figure">
        <div class="figure">
            <xsl:apply-templates/>
        </div>
    </xsl:template>
    
    <xsl:template match="p:caption">
        <div class="caption"> 
            <xsl:choose>
                <xsl:when test="count(parent::p:figure) > 0">
                    <span class="caption-prefix">Obr.: </span>
                </xsl:when>
                <xsl:when test="count(parent::p:table) > 0">
                    <span class="caption-prefix">Tab.: </span>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates/>
        </div>
    </xsl:template>
   
    <xsl:template match="p:math">
        <xsl:choose>
            <xsl:when test="@type='AsciiMath'"> <!-- AsciiMath / inline ... don't have block (yet)-->
                <xsl:text>`</xsl:text>
                <xsl:value-of select="." />
                <xsl:text>`</xsl:text>
            </xsl:when>
            <xsl:when test="@type='MathML' and @display='block'"> <!-- MathML / block -->
                <math xmlns="http://www.w3.org/1998/Math/MathML" display="block">
                    <xsl:apply-templates  select="child::*" mode="Math-copy-no-namespaces"/>
                    <!--                    <xsl:copy-of select="child::*" copy-namespaces="no"/>-->
                </math>
            </xsl:when>
            <xsl:when test="@type='MathML'"> <!-- MathML / inline -->
                <math xmlns="http://www.w3.org/1998/Math/MathML">
                    <xsl:apply-templates  select="child::*" mode="Math-copy-no-namespaces"/>
                    <!--<xsl:copy-of select="child::*" copy-namespaces="no"/>-->
                </math>
            </xsl:when>
            <xsl:when test="@display='block'"> <!-- Tex / block -->
                <xsl:text>\[</xsl:text>
                <xsl:value-of select="." />
                <xsl:text>\]</xsl:text>
            </xsl:when>
            <xsl:otherwise> <!-- Tex / inline -->
                <xsl:text>\(</xsl:text>
                <xsl:value-of select="." />
                <xsl:text>\)</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="*" mode="Math-copy-no-namespaces">
        <xsl:element name="{local-name()}" namespace="http://www.w3.org/1998/Math/MathML">
            <xsl:copy-of select="@*"/>
            <xsl:apply-templates select="@*|node()" mode="Math-copy-no-namespaces"/>
        </xsl:element>
    </xsl:template>
    
    <xsl:template match="p:image">
        <div class="image">
            <img>
                <xsl:attribute name="src">resources/<xsl:value-of select="." /></xsl:attribute>
            </img>
        </div>
    </xsl:template>
    
    <xsl:template match="p:table">
        <div class="table">
            <table>
                <xsl:apply-templates/>
            </table>
        </div>
    </xsl:template> 
    
    <xsl:template match="p:row">
        <xsl:choose>
            <xsl:when test="count(following-sibling::*) = 0">
                <tr class="lastRow">
                    <xsl:apply-templates/>
                </tr>
            </xsl:when>
            <xsl:otherwise>
                <tr>
                    <xsl:apply-templates/>
                </tr>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="p:col">
        <xsl:choose>
            <xsl:when test="count(parent::p:header) > 0">
                <th>
                    <xsl:apply-templates/>
                </th>
            </xsl:when>
            <xsl:when test="count(parent::p:row) > 0">
                <td>
                    <xsl:apply-templates/>
                </td>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="p:header" name="header">
        <thead>
            <tr>
                <xsl:apply-templates/>
            </tr>
        </thead>
    </xsl:template>  
</xsl:stylesheet>
